@@ -2,7 +2,7 @@
    Copyright (C) 2000, 2001, 2002, 2003 Cris van Pelt
    Copyright (C) 2003, 2004 Peter Palfrader
 
-   $Id: exit.c 409 2004-04-21 12:20:43Z weasel $
+   $Id: exit.c 483 2004-07-13 17:43:53Z weasel $
 
    Distributed under the terms of the Artistic License.
 */
@@ -67,96 +67,97 @@ exit_help()
     print_usage(stdout);
 
     printf(_("\nThe following options are available:\n"));
-#ifdef HAVE_GETOPT_LONG
+    /* General option */
     printf("--help,           ");
-#endif
     printf(_("-h        This help.\n"));
-#ifdef HAVE_GETOPT_LONG
-    printf("--version,        ");
-#endif
-    printf(_("-v        Version information.\n"));
-#ifdef HAVE_GETOPT_LONG
-    printf("--status-file,    ");
-#endif
-    printf(_("-f FILE   Use FILE as statusfile.\n"));
-#ifdef HAVE_GETOPT_LONG
-    printf("--show-deps,      ");
-#endif
-    printf(_("-d        Show dependencies for packages that have them.\n"));
-#ifdef HAVE_GETOPT_LONG
-    printf("--nice-mode,      ");
-#endif
 
+    printf("--version,        ");
+    printf(_("-v        Version information.\n"));
+
+    printf("--status-file,    ");
+    printf(_("-f FILE   Use FILE as statusfile.\n"));
+
+
+    /* output modifiers */
+    printf("--show-deps,      ");
+    printf(_("-d        Show dependencies for packages that have them.\n"));
+
+    printf("--show-priority,  ");
+    printf(_("-P        Show priority of packages found.\n"));
+
+    printf("--show-size,      ");
+    printf(_("-z        Show installed size of packages found.\n"));
+
+    printf("--show-section,   ");
+    printf(_("-s        Show the sections the packages are in.\n"));
+
+    printf(_("--no-show-section           Do not show sections.\n"));
+
+
+    /* search modifiers */
+    printf("--nice-mode,      ");
 #ifdef DEFAULT_NICE
     printf(_("-n        Disable checks for `recommends' and `suggests'.\n"));
 #else
     printf(_("-n        Enable checks for `recommends' and `suggests'.\n"));
 #endif
-#ifdef HAVE_GETOPT_LONG
+
     printf("--all-packages,   ");
-#endif
     printf(_("-a        Compare all packages, not just libs.\n"));
-#ifdef HAVE_GETOPT_LONG
+
+    printf(_("--libdevel                  Search in libdevel in addition to libs and oldlibs.\n"));
+
+    printf("--exclude,        ");
+    printf(_("-e LIST   Work as if packages in LIST were not installed.\n"));
+
     printf("--priority,       ");
-#endif
     printf(_("-p PRIOR  Select only packages with priority >= PRIOR.\n"));
-#ifdef HAVE_GETOPT_LONG
-    printf("--show-section,   ");
-#endif
-    printf(_("-s        Show the sections the packages are in.\n"));
-#ifdef HAVE_GETOPT_LONG
-    printf(_("--no-show-section           Do not show sections.\n"));
-#endif
-#ifdef HAVE_GETOPT_LONG
-    printf("--show-priority,  ");
-#endif
-    printf(_("-P        Show the packages' priorities.\n"));
-#ifdef HAVE_GETOPT_LONG
-    printf(_("--find-config,              Find \"orphaned\" configuration files.\n"));
+
     printf("--force-hold,     ");
-#endif
     printf(_("-H        Ignore hold flags.\n"));
-#ifdef HAVE_GETOPT_LONG
-    printf(_("--guess-dev,                Try to report development packages.\n"));
-    printf(_("--guess-perl,               Try to report perl libraries.\n"));
-    printf(_("--guess-section,            Try to report libraries in wrong sections.\n"));
-    printf(_("--guess-debug,              Try to report debugging libraries.\n"));
-    printf(_("--guess-python,             Try to report python libraries.\n"));
-    printf(_("--guess-pike,               Try to report pike libraries.\n"));
-    printf(_("--guess-ruby,               Try to report ruby libraries.\n"));
-    printf(_("--guess-interpreters,       Try to report interpreter libraries.\n"));
-    printf(_("--guess-dummy,              Try to report dummy packages.\n"));
-    printf(_("--guess-common,             Try to report common packages.\n"));
-    printf(_("--guess-data,               Try to report data packages.\n"));
-    printf(_("--guess-all,                Try all of the above.\n"));
-#endif
-#ifdef HAVE_GETOPT_LONG
-    printf(_("--guess-only,               Use --guess options only.\n"));
-#endif
-#ifdef HAVE_GETOPT_LONG
+
+    printf(_("--find-config               Find \"orphaned\" configuration files.\n"));
+
+
+    /* keep file management */
     printf("--add-keep,       ");
-#endif
     printf(_("-A PKGS.. Never report PKGS.\n"));
-#ifdef HAVE_GETOPT_LONG
+
     printf("--del-keep,       ");
-#endif
     printf(_("-R PKGS.. Report PKGS if there are no dependencies.\n"));
-#ifdef HAVE_GETOPT_LONG
+
     printf("--list-keep,      ");
-#endif
     printf(_("-L        List the packages that are never reported.\n"));
-#ifdef HAVE_GETOPT_LONG
+
     printf("--zero-keep,      ");
-#endif
-    printf(_("-Z        Remove all packages from the keep file.\n"));
-#ifdef HAVE_GETOPT_LONG
+    printf(_("-Z        Remove all packages from the \"keep\" file.\n"));
+
     printf("--keep-file,      ");
-#endif
     printf(_("-k FILE   Use FILE to get/store info about kept packages.\n"));
-#if (defined HAVE_GETOPT_LONG) && (defined DEBFOSTER_KEEP)
-    printf(_("--df-keep,                  Read debfoster's keepers file.\n"));
-    printf(_("--no-df-keep,               Do not read debfoster's keepers file.\n"));
+
+#ifdef DEBFOSTER_KEEP
+    printf(_("--df-keep                   Read debfoster's \"keepers\" file.\n"));
+    printf(_("--no-df-keep                Do not read debfoster's \"keepers\" file.\n"));
 #endif
+
+    /* guessing */
+
+    printf(_("--guess-perl                Try to report perl libraries.\n"));
+    printf(_("--guess-python              Try to report python libraries.\n"));
+    printf(_("--guess-pike                Try to report pike libraries.\n"));
+    printf(_("--guess-ruby                Try to report ruby libraries.\n"));
+    printf(_("--guess-interpreters        Try to report interpreter libraries.\n"));
+
+    printf(_("--guess-section             Try to report libraries in wrong sections.\n"));
+    printf(_("--guess-dev                 Try to report development packages.\n"));
+    printf(_("--guess-debug               Try to report debugging libraries.\n"));
+    printf(_("--guess-common              Try to report common packages.\n"));
+    printf(_("--guess-data                Try to report data packages.\n"));
+    printf(_("--guess-doc                 Try to report documentation packages.\n"));
+    printf(_("--guess-dummy               Try to report dummy packages.\n"));
+    printf(_("--guess-all                 Try all of the above.\n"));
+    printf(_("--guess-only                Use --guess options only.\n"));
+
     printf(_("\n\
 See also: deborphan(1), orphaner(8)\n\
 Report bugs to: Peter Palfrader <weasel@debian.org>\n"));
