@@ -2,7 +2,7 @@
    Copyright (C) 2000, 2001, 2002, 2003 Cris van Pelt
    Copyright (C) 2003, 2004 Peter Palfrader
 
-   $Id: pkginfo.c 409 2004-04-21 12:20:43Z weasel $
+   $Id: pkginfo.c 499 2004-10-01 21:50:01Z weasel $
 
    Distributed under the terms of the Artistic License.
 */
@@ -112,6 +112,11 @@ get_pkg_info(const char *line, pkg_info * package)
     const char c = upcase(line[0]);
     char t;
 
+    if (strchr(line, ':') == 0) {
+	fprintf(stderr, "Status file is probably invalid. Exiting.\n");
+	exit (1);
+    }
+
     switch (c) {
     case 'P':
 	t = upcase(line[2]);
