@@ -1,20 +1,16 @@
+/* string.c - some string handling functions.
+   Copyright (C) 2000, 2001, 2002, 2003 Cris van Pelt
+   Copyright (C) 2003, 2004 Peter Palfrader
+
+   $Id: string.c 409 2004-04-21 12:20:43Z weasel $
+
+   Distributed under the terms of the Artistic License.
+*/
 #include <string.h>
 
 #include <deborphan.h>
 #include <xalloc.h>
 
-/* This function compares two 'dep' structures. It returns 1 if the packages
-   match, 0 if they do not.
-*/
-inline unsigned int
-pkgcmp(const dep a, const dep b)
-{
-    if (a.namehash == b.namehash)
-	return (strcmp(a.name, b.name) ? 0 : 1);
-
-    return 0;
-}
-
 /* Simple function to hash a string to an unsigned int. 
 */
 inline unsigned int
@@ -39,8 +35,10 @@ strstripchr(char *s, int c)
 {
     register char *t;
 
-    /* No need to shift while c is not found. Thank you, Wessel. */
-    for (; *s && *s != c; s++);
+    s = strchr(s, c);
+    if (!(s && *s)) 
+	return;
+
     t = s;
 
     do {
@@ -48,8 +46,30 @@ strstripchr(char *s, int c)
 	    *(t++) = *s;
     }
     while (*(s++));
+}
 
-    *t = '\0';
+/* Searches for c in *str. *str is updated to point past the first occurrence 
+ * of c. And a copy (which has to be free()d by the main program!), starting
+ * from the beginning and ending at the character before the first occurence
+ * of c, is returned. On error NULL is returned.
+ *
+ * *str[n] is not modified. *str is, though!
+ */
+char *
+sstrsep(char **str, int c)
+{
+    char *t, *new;
+
+    if (! (**str && *str))
+	return NULL;
+    
+    t = strchr(*str, c);
+    new = (char *) xmalloc((size_t) (t - (*str)) + 1); /* Safe? */
+    memcpy(new, *str, t - *str + 1);
+    *(new + (t - (*str))) = '\0';
+    *str = t + 1;
+
+    return new;
 }
 
 int
